==> splitit-web-python-sdk-1.0.1.tar.gz: splitit-web-python-sdk-1.0.1/splitit_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from splitit_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from splitit_client.model.address_data import AddressData
from splitit_client.model.address_data_model import AddressDataModel
from splitit_client.model.authorization_model import AuthorizationModel
from splitit_client.model.card_data import CardData
from splitit_client.model.error import Error
from splitit_client.model.error_extended import ErrorExtended
from splitit_client.model.error_extended_all_of import ErrorExtendedAllOf
from splitit_client.model.failed_response import FailedResponse
from splitit_client.model.failed_response_all_of import FailedResponseAllOf
from splitit_client.model.gw_authorization_status import GwAuthorizationStatus
from splitit_client.model.identifier_contract import IdentifierContract
from splitit_client.model.installment import Installment
from splitit_client.model.installment_plan_cancel_response import InstallmentPlanCancelResponse
from splitit_client.model.installment_plan_create_request import InstallmentPlanCreateRequest
from splitit_client.model.installment_plan_get_response import InstallmentPlanGetResponse
from splitit_client.model.installment_plan_get_response_all_of import InstallmentPlanGetResponseAllOf
from splitit_client.model.installment_plan_model import InstallmentPlanModel
from splitit_client.model.installment_plan_model_all_of import InstallmentPlanModelAllOf
from splitit_client.model.installment_plan_refund_request import InstallmentPlanRefundRequest
from splitit_client.model.installment_plan_refund_response import InstallmentPlanRefundResponse
from splitit_client.model.installment_plan_refund_response_all_of import InstallmentPlanRefundResponseAllOf
from splitit_client.model.installment_plan_update_request import InstallmentPlanUpdateRequest
from splitit_client.model.installment_plan_update_request_by_identifier import InstallmentPlanUpdateRequestByIdentifier
from splitit_client.model.installment_plan_update_request_by_identifier_all_of import InstallmentPlanUpdateRequestByIdentifierAllOf
from splitit_client.model.installment_plan_update_response import InstallmentPlanUpdateResponse
from splitit_client.model.installment_plan_update_response_all_of import InstallmentPlanUpdateResponseAllOf
from splitit_client.model.installment_status import InstallmentStatus
from splitit_client.model.links_data import LinksData
from splitit_client.model.payment_method_model import PaymentMethodModel
from splitit_client.model.payment_method_type import PaymentMethodType
from splitit_client.model.plan_data_model import PlanDataModel
from splitit_client.model.plan_error_response import PlanErrorResponse
from splitit_client.model.plan_error_response_all_of import PlanErrorResponseAllOf
from splitit_client.model.plan_status import PlanStatus
from splitit_client.model.purchase_method import PurchaseMethod
from splitit_client.model.redirection_endpoints_model import RedirectionEndpointsModel
from splitit_client.model.refund_strategy import RefundStrategy
from splitit_client.model.refund_summary import RefundSummary
from splitit_client.model.response_v2 import ResponseV2
from splitit_client.model.shipping_status import ShippingStatus
from splitit_client.model.shipping_status2 import ShippingStatus2
from splitit_client.model.shopper_data import ShopperData
from splitit_client.model.test_modes import TestModes
from splitit_client.model.three_ds_redirect_data import ThreeDsRedirectData
from splitit_client.model.update_order_request import UpdateOrderRequest
from splitit_client.model.verify_authorization_response import VerifyAuthorizationResponse
from splitit_client.model.verify_authorization_response_all_of import VerifyAuthorizationResponseAllOf

==> splitit-web-python-sdk-2.1.0.tar.gz: splitit-web-python-sdk-2.1.0/splitit_client/models/__init__.py <==
# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from splitit_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from splitit_client.model.address_data import AddressData
from splitit_client.model.address_data_model import AddressDataModel
from splitit_client.model.authorization_model import AuthorizationModel
from splitit_client.model.card_brand import CardBrand
from splitit_client.model.card_data import CardData
from splitit_client.model.card_type import CardType
from splitit_client.model.check_installments_eligibility_request import CheckInstallmentsEligibilityRequest
from splitit_client.model.error import Error
from splitit_client.model.error_extended import ErrorExtended
from splitit_client.model.failed_response import FailedResponse
from splitit_client.model.gw_authorization_status import GwAuthorizationStatus
from splitit_client.model.identifier_contract import IdentifierContract
from splitit_client.model.initiate_plan_response import InitiatePlanResponse
from splitit_client.model.initiate_redirection_endpoints_model import InitiateRedirectionEndpointsModel
from splitit_client.model.installment import Installment
from splitit_client.model.installment_plan_cancel_response import InstallmentPlanCancelResponse
from splitit_client.model.installment_plan_create_request import InstallmentPlanCreateRequest
from splitit_client.model.installment_plan_create_response import InstallmentPlanCreateResponse
from splitit_client.model.installment_plan_get_response import InstallmentPlanGetResponse
from splitit_client.model.installment_plan_initiate_request import InstallmentPlanInitiateRequest
from splitit_client.model.installment_plan_refund_request import InstallmentPlanRefundRequest
from splitit_client.model.installment_plan_refund_response import InstallmentPlanRefundResponse
from splitit_client.model.installment_plan_search_response import InstallmentPlanSearchResponse
from splitit_client.model.installment_plan_update_request import InstallmentPlanUpdateRequest
from splitit_client.model.installment_plan_update_request_by_identifier import InstallmentPlanUpdateRequestByIdentifier
from splitit_client.model.installment_plan_update_response import InstallmentPlanUpdateResponse
from splitit_client.model.installment_status import InstallmentStatus
from splitit_client.model.installments_eligibility_response import InstallmentsEligibilityResponse
from splitit_client.model.links_data import LinksData
from splitit_client.model.links_model import LinksModel
from splitit_client.model.payment_method_model import PaymentMethodModel
from splitit_client.model.payment_method_type import PaymentMethodType
from splitit_client.model.payment_plan_option_model import PaymentPlanOptionModel
from splitit_client.model.plan_data import PlanData
from splitit_client.model.plan_data_model import PlanDataModel
from splitit_client.model.plan_error_response import PlanErrorResponse
from splitit_client.model.plan_status import PlanStatus
from splitit_client.model.purchase_method import PurchaseMethod
from splitit_client.model.redirection_endpoints_model import RedirectionEndpointsModel
from splitit_client.model.refund_model import RefundModel
from splitit_client.model.refund_status import RefundStatus
from splitit_client.model.refund_strategy import RefundStrategy
from splitit_client.model.refund_summary import RefundSummary
from splitit_client.model.search_installment_plan_response_item import SearchInstallmentPlanResponseItem
from splitit_client.model.shipping_status import ShippingStatus
from splitit_client.model.shipping_status2 import ShippingStatus2
from splitit_client.model.shopper_data import ShopperData
from splitit_client.model.test_modes import TestModes
from splitit_client.model.three_ds_redirect_data_v3 import ThreeDsRedirectDataV3
from splitit_client.model.update_order_request import UpdateOrderRequest
from splitit_client.model.ux_settings_model import UxSettingsModel
from splitit_client.model.verify_authorization_response import VerifyAuthorizationResponse
